#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Author: Michael Dvorak - specialis IT GmbH
# Version: 1.0 - 2021-12-27

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Age,
    Alternative,
    CascadingDropdown,
    Checkbox,
    Dictionary,
    DropdownChoice,
    Filesize,
    FixedValue,
    Integer,
    ListOf,
    ListOfStrings,
    RegExp,
    RegExpUnicode,
    TextAscii,
    TextUnicode,
    Transform,
    Tuple,
)
from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    RulespecGroupCheckParametersApplications,
    rulespec_registry,
)
    
def _parameter_valuespec_defender_state():
    return Dictionary(
        title=_('Levels for signature and QuickScan age'),
        elements=[
            ("signature_age", Tuple(
                title=_("Levels for signature age"),
                elements=[
                    Integer(title=_("Warning at (days)"), default_value=3),
                    Integer(title=_("Critical at (days)"), default_value=5),
                ],
             )), 
            ("quickscan_age", Tuple(
                title=_("Levels for QuickScan age in days"),
                elements=[
                    Integer(title=_("Warning at (days)"), default_value=2),
                    Integer(title=_("Critical at (days)"), default_value=3),
                ],
             )),
        ],
    )
    
rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="spit_defender_state",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_defender_state,
        title=lambda: _("Defender Signature and QuickScan age"),
    ))
